@@ -2,10 +2,11 @@ import Planner from './components/planner';
 import Catalog from './catalog/catalog';
 import ToolbarButton from './components/toolbar/toolbar-button';
 import Ruler from './components/viewer2d/ruler';
+import * as Models from './models'
 
 console.info(`react-planner started`); //MIT LICENSE COMPLIANT
 
 
 export {
-  Planner, Catalog, ToolbarButton, Ruler
+  Planner, Catalog, ToolbarButton, Ruler, Models
 };
